tlslite.messages.Certificate

Package tlslite :: Module messages :: Class Certificate |
[hide private]
[frames] | no frames]

# Class Certificate

source code

    HandshakeMsg --+
                   |
                  Certificate

Instance Methods | [hide private]
__init__(self, certificateType) | source code
create(self, certChain) | source code
parse(self, p) | source code
write(self) | source code
Inherited from `HandshakeMsg`: `postWrite`

Method Details | [hide private]

### __init__(self, certificateType) (Constructor) | source code
Overrides: HandshakeMsg.__init__